@@ -3,7 +3,6 @@ from hy.compiler.ast27 import forge_module
 
 from hy.lex.tokenize import tokenize
 import sys
-import imp
 import os
 
 
@@ -54,6 +53,7 @@ class MetaLoader(HyFinder):
 
         mod.__file__ = pth
         mod.__loader__ = self
+        mod.__name__ = fullname
 
         if ispkg:
             mod.__path__ = []
