@@ -28,8 +28,14 @@ def _resolve_atom(value, self):
     except ValueError:
         pass
 
+    # LISP Variants tend to use *foo* for constants. Let's make it
+    # the more pythonic "FOO"
+    if value.startswith("*") and value.endswith("*") and len(value) > 1:
+        value = value.upper()[1:-1]
+
     # LISP Variants have a tendency to use "-" in symbols n' shit.
-    value = value.replace("-", "_")
+    if value != "-":  # we need subtraction
+        value = value.replace("-", "_")
 
     return _mangle(HYSymbol(value))
 
@@ -68,17 +74,22 @@ class Comment(State):
 
 class Idle(State):
     def p(self, x):
-        if x == "#": return HashExpression
-        if x == ";": return Comment
-        if x == "(": return Expression
-        if x in WHITESPACE: return
+        if x == "#":
+            return HashExpression
+        if x == ";":
+            return Comment
+        if x == "(":
+            return Expression
+        if x in WHITESPACE:
+            return
 
         raise LexException("Unknown char: %s" % (x))
 
 
 class HashExpression(State):
     def p(self, x):
-        if x == "!": return Comment
+        if x == "!":
+            return Comment
 
         raise LexException("Unknwon Hash modifier - %s" % (x))
 
@@ -100,13 +111,26 @@ class Expression(State):
             self.bulk = ""
 
     def p(self, x):
-        if x == ")": return Idle
-        if x in WHITESPACE: self.commit(); return
-        if x == "\"": self.sub(String); return
-        if x == "(": self.sub(Expression); return
-        if x == "[": self.sub(List); return
-        if x == "{": self.sub(Map); return
-        if x == ";": self.sub(Comment); return
+        if x == ")":
+            return Idle
+        if x in WHITESPACE:
+            self.commit()
+            return
+        if x == "\"":
+            self.sub(String)
+            return
+        if x == "(":
+            self.sub(Expression)
+            return
+        if x == "[":
+            self.sub(List)
+            return
+        if x == "{":
+            self.sub(Map)
+            return
+        if x == ";":
+            self.sub(Comment)
+            return
         self.bulk += x
 
 
@@ -126,13 +150,26 @@ class List(State):
             self.bulk = ""
 
     def p(self, x):
-        if x == "]": return Idle
-        if x in WHITESPACE: self.commit(); return
-        if x == "\"": self.sub(String); return
-        if x == "[": self.sub(List); return
-        if x == "(": self.sub(Expression); return
-        if x == "{": self.sub(Map); return
-        if x == ";": self.sub(Comment); return
+        if x == "]":
+            return Idle
+        if x in WHITESPACE:
+            self.commit()
+            return
+        if x == "\"":
+            self.sub(String)
+            return
+        if x == "[":
+            self.sub(List)
+            return
+        if x == "(":
+            self.sub(Expression)
+            return
+        if x == "{":
+            self.sub(Map)
+            return
+        if x == ";":
+            self.sub(Comment)
+            return
         self.bulk += x
 
 
@@ -161,18 +198,31 @@ class Map(State):
             self.bulk = ""
 
     def p(self, x):
-        if x == "}": return Idle
-        if x in WHITESPACE: self.commit(); return
-        if x == "\"": self.sub(String); return
-        if x == "[": self.sub(List); return
-        if x == "{": self.sub(Map); return
-        if x == "(": self.sub(Expression); return
-        if x == ";": self.sub(Comment); return
+        if x == "}":
+            return Idle
+        if x in WHITESPACE:
+            self.commit()
+            return
+        if x == "\"":
+            self.sub(String)
+            return
+        if x == "[":
+            self.sub(List)
+            return
+        if x == "{":
+            self.sub(Map)
+            return
+        if x == "(":
+            self.sub(Expression)
+            return
+        if x == ";":
+            self.sub(Comment)
+            return
         self.bulk += x
 
 
 class String(State):
-    magic = { "n": "\n", "t": "\t", "\\": "\\", "\"": "\"" }
+    magic = {"n": "\n", "t": "\t", "\\": "\\", "\"": "\""}
 
     def enter(self):
         self.buf = ""
